@@ -34,6 +34,14 @@
 #include <stdlib.h>
 #include <string.h>
 #include <stdio.h>
+#if defined(__unix__)
+  // features.h is unix-specific?
+  #include <features.h>
+
+  #if __GLIBC_PREREQ(2, 3)
+  asm (".symver memcpy, memcpy@GLIBC_2.2.5");
+  #endif
+#endif  /* __unix__ */
 
 #if PY_MAJOR_VERSION == 2 && PY_MINOR_VERSION < 5
 typedef int Py_ssize_t;
